Skip to contents

Get clusters containing more than one patient

Usage

get_non_single_patient_clusters(isolate_lookup)

Arguments

isolate_lookup

A lookup table for isolates and their cluster assignments with other relevant epidemiological information. See get_isolate_lookup().

Value

A numeric vector of cluster IDs that contain isolates from more than one patient.