Remove singleton clusters from a vector of cluster assignments
Source:R/cluster_utils.R
remove_singleton_clusters.RdDrops clusters made up of a single sequence, preserving the original cluster values and isolate
names of the rest. Note that a singleton is counted by sequence here, unlike
get_non_single_patient_clusters(), which counts distinct patients.