Summarize isolate overlap within each cluster
Source:R/cluster_overlap.R
cluster_isolate_overlap.RdFor each isolate in a cluster (treated as a recipient), reports whether any other isolate in the
same cluster (as a donor) overlaps with it, using the isolate-pair overlaps from
isolate_isolate_overlap() or isolate_isolate_sequential_overlap(). Admission-positive
isolates are reported as NA, since they were not acquired in the facility.
Arguments
- isolate_lookup
A lookup table for isolates and their cluster assignments with other relevant epidemiological information. See
get_isolate_lookup().- iso_overlap_df
A data frame of isolate-pair overlaps, from
isolate_isolate_overlap().