Compute a pairwise SNP distance matrix from a DNA alignment
Source:R/utils.R
get_snp_dist_matrix.RdCounts the number of nucleotide differences between every pair of sequences, via
ape::dist.dna() with model "N".
R/utils.R
get_snp_dist_matrix.RdCounts the number of nucleotide differences between every pair of sequences, via
ape::dist.dna() with model "N".